///////////////////////////////////////////////////
/////                                         /////
/////   Author:   Delphir                     /////
/////   Version:  1.0                         /////
/////   www:      http://delphi5.times.lv     /////
/////   E-mail:   delphir@e-apollo.lv         /////
/////                                         /////
///////////////////////////////////////////////////



unit MSG;

interface

uses
  SysUtils, Classes, forms, Windows, dialogs;

type
	TBrowseInfoButtons=(Ok, Ok_Cancel, Abort_Retry_Ignore, Yes_No_Cancel, Yes_No, Retry_Cancel, Help, Cancel_Help, Ok_Cancel_Help, Help_Ok_Cancel_Help, Ok_Cancel_Help_Abort_Retry);
        TBrowseInfoIcons=(None, Error, Question, Exclamation,Information);
        TBrowseInfoMsgType=(Standart, IconMsg, EditMsg);

          TMSG = class(TCommonDialog)

  private
    { Private declarations }
      FText: string;
      FTitle: string;
      FDescription: string;
      FButtons : TBrowseInfoButtons;
      FIcon : TBrowseInfoIcons;
      FMsgType : TBrowseInfoMsgType;
       FOnOkClick      : TNotifyEvent;
       FOnCancelClick  : TNotifyEvent;
       FOnYesClick     : TNotifyEvent;
       FOnNoClick      : TNotifyEvent;
       FOnIgnoreClick  : TNotifyEvent;
       FOnRetryClick   : TNotifyEvent;
       FOnAbortClick   : TNotifyEvent;
      procedure SetText(const Value: string);
      procedure SetTitle(const Value: string);
      procedure SetDescription(const Value: string);
  protected
     { Protected declarations }
      procedure DoOkClick; dynamic;
      procedure DoCancelClick; dynamic;
      procedure DoYesClick; dynamic;
      procedure DoNoClick; dynamic;
      procedure DoIgnoreClick; dynamic;
      procedure DoRetryClick; dynamic;
      procedure DoAbortClick; dynamic;
  public
    { Public declarations }
  function Execute: Boolean; override;
  published
    { Published declarations }
      property OnOkClick: TNotifyEvent read FOnOkClick write FOnOkClick;
      property OnCancelClick: TNotifyEvent read FOnCancelClick write FOnCancelClick;
      property OnYesClick: TNotifyEvent read FOnYesClick write FOnYesClick;
      property OnNoClick: TNotifyEvent read FOnNoClick write FOnNoClick;
      property OnIgnoreClick: TNotifyEvent read FOnIgnoreClick write FOnIgnoreClick;
      property OnRetryClick: TNotifyEvent read FOnRetryClick write FOnRetryClick;
      property OnAbortClick: TNotifyEvent read FOnAbortClick write FOnAbortClick;

      property Buttons : TBrowseInfoButtons read FButtons write FButtons default Ok;
      property Icon : TBrowseInfoIcons read FIcon write FIcon default None;
      property MsgType : TBrowseInfoMsgType read FMsgType write FMsgType default Standart;
      property Text: string read FText write SetText;
      property Title: string read FTitle write SetTitle;
      property Description: string read FDescription write SetDescription;
  end;

procedure Register;

implementation

procedure Register;
begin
  RegisterComponents('Standard', [TMSG]);
end;

{ TMSG }

procedure TMsg.SetText(const Value: string);
var
  L: Integer;
begin
  L := Length(Value);
  if (L > 1) and IsPathDelimiter(Value, L)
    and not IsDelimiter(':', Value, L - 1) then Dec(L);
  FText := Copy(Value, 1, L);
end;

procedure TMsg.SetTitle(const Value: string);
var
  L: Integer;
begin
  L := Length(Value);
  if (L > 1) and IsPathDelimiter(Value, L)
    and not IsDelimiter(':', Value, L - 1) then Dec(L);
  FTitle := Copy(Value, 1, L);
end;

procedure TMsg.SetDescription(const Value: string);
var
  L: Integer;
begin
  L := Length(Value);
  if (L > 1) and IsPathDelimiter(Value, L)
    and not IsDelimiter(':', Value, L - 1) then Dec(L);
  FDescription := Copy(Value, 1, L);
end;

function TMSG.Execute: Boolean;
var
 text: string;
 opt: integer;
 res: integer;
begin
opt:=0;
     if fbuttons = Ok then
   begin
   opt := 0;
   end;
     if fbuttons = Ok_Cancel then
   begin
   opt := 1;
   end;
        if fbuttons = Abort_Retry_Ignore then
   begin
   opt := 2;
   end;
        if fbuttons = Yes_No_Cancel then
   begin
   opt := 3;
   end;
        if fbuttons = Yes_No then
   begin
   opt := 4;
   end;
        if fbuttons = Retry_Cancel then
   begin
   opt := 5;
   end;
        if fbuttons = Help then
   begin
   opt := 6;
   end;
        if fbuttons = Cancel_Help then
   begin
   opt := 8;
   end;
        if fbuttons = Ok_Cancel_Help then
   begin
   opt := 10;
   end;
        if fbuttons = Help_Ok_Cancel_Help then
   begin
   opt := 12;
   end;
        if fbuttons = Ok_Cancel_Help_Abort_Retry then
   begin
   opt := 14;
   end;
        if ficon = None then
         begin
         opt := opt;
         end;
        if ficon = Error then
         begin
         opt := opt+16;
         end;
        if ficon = Question then
         begin
         opt := opt+16*2;
         end;
        if ficon = Exclamation then
         begin
         opt := opt+16*3;
         end;
        if ficon = Information then
         begin
         opt := opt+16*4;
         end;

if FMsgType = Standart then
 begin
 showmessage(FText);
 end;
if FMsgType = EditMsg then
 begin
  if inputQuery(Title, Description, text)then
   begin
   FText := text;
   end;
 end;
if FMsgType = IconMsg then
 begin
  res := (Application.MessageBox(pchar(FText),pchar(FTitle), opt));
  if res = IDOK then
   begin
   DOOkClick;
   end;
  if res = IDCANCEL then
   begin
   DOCancelClick;
   end;
  if res = IDYES then
   begin
   DOYesClick;
   end;
  if res = IDNO then
   begin
   DONoClick;
   end;
  if res = IDIGNORE then
   begin
   DOIgnoreClick;
   end;
  if res = IDRETRY then
   begin
   DORetryClick;
   end;
  if res = IDABORT then
   begin
   DOAbortClick;
   end;
 end;
end;

procedure TMSG.DoAbortClick;
begin
 if Assigned(FOnAbortClick) then FOnAbortClick(Self);
end;

procedure TMSG.DoCancelClick;
begin
 if Assigned(FOnCancelClick) then FOnCancelClick(Self);
end;

procedure TMSG.DoIgnoreClick;
begin
 if Assigned(FOnIgnoreClick) then FOnIgnoreClick(Self);
end;

procedure TMSG.DoNoClick;
begin
 if Assigned(FOnNoClick) then FOnNoClick(Self);
end;

procedure TMSG.DoOkClick;
begin
 if Assigned(FOnOkClick) then FOnOkClick(Self);
end;

procedure TMSG.DoRetryClick;
begin
 if Assigned(FOnRetryClick) then FOnRetryClick(Self);
end;

procedure TMSG.DoYesClick;
begin
 if Assigned(FOnYesClick) then FOnYesClick(Self);
end;

end.
